"""Configuration for the Copilot CLI session adapter."""

from pathlib import Path

from pydantic import BaseModel


class CopilotConfig(BaseModel):
    """Configuration for locating Copilot CLI session files."""

    session_dir: Path = Path.home() / ".copilot" / "session-state"
